@@ -2,7 +2,7 @@
 
 #
 # DaVinci Resolve 16.0 Debian package creator
-# Release 2019-09-27
+# Release 2019-09-29
 # By Daniel Tufvesson
 #
 
@@ -58,7 +58,7 @@ make_executable() {
 
 # Setup variables
 RESOLVE_VERSION=16.0
-DEB_STEPPING=3
+DEB_STEPPING=4
 case $1 in
     studio)
 	RESOLVE_NAME="DaVinci Resolve Studio"
@@ -179,10 +179,16 @@ chmod -R a+rw /opt/resolve/easyDCP
 chmod -R a+rw /opt/resolve/LUT
 chmod -R a+rw /opt/resolve/.license
 chmod -R a+rw /var/BlackmagicDesign/"DaVinci Resolve"
-test ! -e /usr/lib64 && ln -s /usr/lib/x86_64-linux-gnu/ /usr/lib64
+test ! -e /usr/lib64 && ln -s /usr/lib/x86_64-linux-gnu/ /usr/lib64 && touch /usr/lib64_link_created_by_makeresolvedeb
 exit 0
 EOF
 make_executable ${DEB_DIR}/DEBIAN/postinst
+cat > ${DEB_DIR}/DEBIAN/postrm <<EOF
+#!/bin/sh
+test -e /usr/lib64_link_created_by_makeresolvedeb && rm /usr/lib64 && rm /usr/lib64_link_created_by_makeresolvedeb
+exit 0
+EOF
+make_executable ${DEB_DIR}/DEBIAN/postrm
 check_command fakeroot
 check_command dpkg-deb
 fakeroot dpkg-deb -b ${DEB_DIR} ${DEB_DIR}.deb
